::cisco::eem::event_register_syslog occurs 1 pattern "\%OSPF-4-DUP_RTRID_NBR: OSPF detected duplicate router-id .* on interface .*"

#------------------------------------------------------------------
# EEM policy to report problem on ospf protocol formation.
#
# June 2007 - Christine Yan (cyan@cisco.com)
#
# Copyright (c) 2007 by cisco Systems, Inc.
# All rights reserved.
#
#
# Version-date: v1.0-06/15/2007
#
#
# Name: ospf_adj_duplicate_rid.tcl
#
# Desc: This script is an application to diagnostic ospf problem. It 
#       report ospf problem to customer which ospf duplicate rid is
#       configured.
#
# Environment Variables for this script are:
#  _send_email_for_adj_duplicate_rid (opt)
#  _svcdiag_adjConfigHistory (opt)
#  _svcdiag_adjEventHistory  (opt)
#  _email_server (opt)
#  _email_from  (opt)
#  _email_to    (opt)
#  _email_cc    (opt)
#
# IOS config:
#
#  conf t
#
#  event manager environment _send_email_for_stuck_cases no
#  event manager environment _svcdiag_adjConfigHistory FALSE
#  event manager environment _svcdiag_adjEventHistory FALSE
#  event manager directory user policy disk0:/svc_diag
#  event manager directory user library disk0:/user_lib
#  event manager policy ospf_adj_duplicate_rid.tcl type user
#
#  event manager environment _email_server email.cisco.com
#  event manager environment _email_from cyan@cisco.com
#  event manager environment _email_to cyan@cisco.com
#  event manager environment _email_cc cyan@cisco.com
# 
#  Please note: on some devices you do have to use
#  event manager directory user policy disk2:/
#
#  For 3825 or 3xxx serial of routers, should use flash: instead of disk0:
#
#  How to run this script:
#
# As soon as the script is registered in config mode, it can be run since it 
# accepts a syslog event.
# c7200-6(config)#event manamger policy ospf_adj_duplicate_rid.tcl
#
#------------------------------------------------------------------
# The namespace import commands that follow import some cisco TCL extensions
# that are required to run this script

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*

# check if all the env variables we need exist
# If any of them doesn't exist, print out an error msg and quit

set send_email 0

if {[info exists _send_email_for_adj_duplicate_rid]} {

    if [regexp yes $_send_email_for_adj_duplicate_rid] {

	# Check if all the env variables we need exist
	# If any of them doesn't exist, print out an error msg and quit

	if {![info exists _email_server]} {
	    set result "Policy \
		cannot be run: variable _email_server has not been set"
	    error $result "_email_server is required for sending email"
	}
	if {![info exists _email_from]} {
	    set result \
		"Policy cannot be run: variable _email_from has not been set"
	    error $result "_email_from is required for sending email"
	}
	if {![info exists _email_to]} {
	    set result \
		"Policy cannot be run: variable _email_to has not been set"
	    error $result "_email_to is required for sending email"
	}
	if {![info exists _email_cc]} {
	    #_email_cc is an option, must set to empty string if not set.
	    set _email_cc ""
	}

	set send_email 1	
    }
}

set config_history 0

if {[info exists _svcdiag_adjConfigHistory]} {
    if { $_svcdiag_adjConfigHistory == "TRUE" } {
	set config_history 1
    }
}

set event_history 0

if {[info exists _svcdiag_adjEventHistory]} {
    if { $_svcdiag_adjEventHistory == "TRUE" } {
	set event_history 1
    }
}

set msg_header "\n\nTHE SERVICE DIAG MESSAGE FOR ADJ DUPLICATE RID is:"
set msg $msg_header

append msg \n\n "The message happens when two routers are configured same "
append msg "router id. Check the router ids on 2 routers to make sure they "
append msg "have individual router ids and restart the ospf protocol by "
append msg "doing \"no router ospf <ospf_id>\" and \"router ospf "
append msg "<ospf_id>\" in configuration mode or \"clear ip ospf "
append msg "<process_id> process\" in super user mode"

if { $msg == $msg_header } {
    append msg \n\n "reason unknown"
}

append msg \n\n "--------------------------------------------------------"
append msg "------"

action_syslog msg $msg

if { $send_email == 0 } {
   send_info $config_history $event_history 
} else {
   send_result_by_email $config_history $event_history $msg $_email_from \
       $_email_to $_email_cc $_email_server
}
