#------------------------------------------------------------------
#
# Sept. 2007 - Christine Yan (cyan@cisco.com)
#
# Copyright (c) 2007 by cisco Systems, Inc.
# All rights reserved.
#
# Version-date: v1.0-09/09/2007
#
# Name: ospf_lib.tcl
#
# Desc: lib procedures to be shared by eem ospf policies
#
#------------------------------------------------------------------

###############################################################################
#
#   Description: get_intf_area_id
#
#   IN: interface ip addresses
#   OUT:return which ospf area the interface is at
#
###############################################################################

proc get_intf_area_id { intf1 intf2 intf3 intf4 } {

    global verbose

    set area_id ""
    
    set cli_out_area [ios_enable_command "show run | i network .* area"]

    foreach line [split $cli_out_area "\r\n"] {
	if { [regexp {network (.*) (.*) area (.*)} $line dummy ospf_addr \
		ospf_mask area_id_num] } {
	    if { $verbose == 1 } {
		puts "line is $line, ospf_addr is $ospf_addr "
		puts "ospf_mask is $ospf_mask area_id_num is $area_id_num"
	    }
	    regexp {([0-9]+).([0-9]+).([0-9]+).([0-9]+)} \
		    $ospf_addr dummy ospf_addr1 ospf_addr2 \
		    ospf_addr3 ospf_addr4
	    regexp {([0-9]+).([0-9]+).([0-9]+).([0-9]+)} \
		    $ospf_mask dummy ospf_mask1 ospf_mask2 \
		    ospf_mask3 ospf_mask4

	    # Reference page 419 of "cisco ios 12.0 solutions for
	    # network protocols volume I: ip" for ospf wildcard calculation.

	    # Logically ORed ospf wildcard-mask with interface address
	    set intf_ospf_mask1 [expr {$intf1 | $ospf_mask1}]
	    set intf_ospf_mask2 [expr {$intf2 | $ospf_mask2}]
	    set intf_ospf_mask3 [expr {$intf3 | $ospf_mask3}]
	    set intf_ospf_mask4 [expr {$intf4 | $ospf_mask4}]

	    # Logically ORed ospf wildcard-mask with network address
	    set network_ospf_mask1 [expr {$ospf_addr1 | $ospf_mask1}]
	    set network_ospf_mask2 [expr {$ospf_addr2 | $ospf_mask2}]
	    set network_ospf_mask3 [expr {$ospf_addr3 | $ospf_mask3}]
	    set network_ospf_mask4 [expr {$ospf_addr4 | $ospf_mask4}]

	    if { $verbose == 1 } {
		puts "intf_ospf_mask $intf_ospf_mask1.$intf_ospf_mask2.\
			$intf_ospf_mask3.$intf_ospf_mask4"
		puts "network_ospf_mask is $network_ospf_mask1.\
                        $network_ospf_mask2.$network_ospf_mask3.\
			$network_ospf_mask4"
	    }

	    # Check if they are match
	    if { ($intf_ospf_mask1 == $network_ospf_mask1) &&
	    ($intf_ospf_mask2 == $network_ospf_mask2) &&
	    ($intf_ospf_mask3 == $network_ospf_mask3) &&
	    ($intf_ospf_mask4 == $network_ospf_mask4) } {
		# It means ospf is enabled on the  interface and
		# the interface is attached to the ospf area id
		append area_id $area_id_num
	    }
	}    
    }

    return $area_id
}
