#------------------------------------------------------------------------------
# Diagnostic script to get the inputs related to "qos problem"  from the
#                   user
#
# August 2007 - Christine Yan (cyan@cisco.com)
#
# Copyright (c) 2007 by cisco Systems, Inc.
# All rights reserved.
#
#
# Version-date: v1.0-06/20/2007 
# Title: Store(configure) inputs from user and register with EEM.
# 
# Name: sdiag_ospf.tcl
#
# Desc: Gets input from customer. Registers the corresponding qos policy
#       "ospf_stuck_cases.tcl" with EEM 
#
#
# Usage: tclsh <dir>:/dir_name/sdiag_ospf.tcl <trigger_policy> 
#        <notification> <configurationHistory>
#        <EventHistory> <policy_dir> <user_lib> 
#
#        The script argument including event environment variables are:
#           <trigger_policy> -- [ ospf_stuck_cases.tcl ]
#           <notification> -- ["email" or "syslog"]
#           <configurationHistory> -- ["TRUE" or "FALSE"]
#           <EventHistory>  -- ["TRUE" or "FALSE"]
#        EEM config to run the policy are:
#           <policy_dir> -- [ disk0:/svc_diag (where the policy is put) ]
#           <user_lib> -- [ disk0:/user_lib ]
#
#------------------------------------------------------------------------------

#############################################################################
#
#    Description: Configure EEM environment variables 
#
#    IN: The inputs given by the user  
#    OUT: Configures the environment variables on the router
 
#############################################################################

#    Execution of the script starts from here 
#    Check if the number of arguments entered by user is correct otherwise send
#          error message. 

set error "Usage:tclsh <disk_name>:/<dir_name>/sdiag_ospf.tcl\
        <policy name> <notification> <configurationHistory>\
        <EventHistory> <policy_dir> <user_lib>" 
 
if {$argc == 6} {

    set trigger_policy [lindex $argv 0]
    set notification [lindex $argv 1]
    set configHistory [lindex $argv 2]
    set eventHistory [lindex $argv 3]
    set policy_dir [lindex $argv 4]
    set user_lib [lindex $argv 5]

} else {
    puts $error
    return
}

# If the notification is email then we check if the email related inputs have
# given by the user previously, otherwise an error message is sent to user
# to given the inputs related to email and what script needs to be invoked
# to do that
       
if ![ regexp {ospf_(.*).tcl} $trigger_policy dummy email_param ] {
    puts "You have wrong argument in triggering policy"
    exit
}

if ![ regexp {ospf_(.*)_.*.tcl} $trigger_policy dummy history_param ] {
    puts "You have wrong argument in triggering policy"
    exit
}

if ![ regexp {(.*)_(.*)} $history_param dummy his_param ] {
    set his_param $history_param
}

if { $notification == "email" } {
    set send_email yes
    if { [catch {exec "show event man env | include _email_to" } result ] \
	    == 0 } {
	if [regexp _email_to $result] {
	    if  {[catch { exec "show event man env | include _email_from" } \
		    result ] == 0 } {
		if [regexp _email_from $result] {
		    if  {[catch { exec "show event man env | include \
			    _email_server" } result ] == 0 } {
			set email_param_setup 1
			puts "email parameter is set up"
		    }
		}
	    }
	}
    } else {
	puts "email parameter is not set up, please run "
	puts "<dir>:/email_setup <email_to> <email_from> <email_server>"
    }
} elseif { $notification == "syslog" } {
    set send_email no
} else {
    puts "Invalid input"
    puts "Enter 'email' or 'syslog' as input\n"
    return
}

source $user_lib/diag_lib.tcl

set_eem_env "_send_email_for_$email_param" $send_email
set c_history "_svcdiag_$his_param"
append c_history "ConfigHistory"
set_eem_env $c_history $configHistory
set e_history "_svcdiag_$his_param"
append e_history "EventHistory"
set_eem_env $e_history $eventHistory
unset_eem_dir "policy"
unset_eem_dir "library"
unreg_eem_policy $trigger_policy
set_eem_dir "policy" $policy_dir
set_eem_dir "library" $user_lib
reg_eem_policy $trigger_policy

#Cisco Tcl Signature V1.0
#3082077506092a864886f70d010702a082076630820762020101310b3009
#06052b0e03021a0500300b06092a864886f70d010701a08204bb308204b7
#3082039fa003020102020900d48b1bbfb069e9b9300d06092a864886f70d
#0101050500308198310b3009060355040613024341311230100603550408
#130963616c69666f6e69613111300f060355040713086d69706c69746173
#311b3019060355040a1312636973636f2073797374656d7320696e632e31
#0e300c060355040b13054e53535447311630140603550403130d43687269
#7374696e652059616e311d301b06092a864886f70d010901160e6379616e
#40636973636f2e636f6d301e170d3037313231383138333232375a170d31
#30313231373138333232375a308198310b30090603550406130243413112
#30100603550408130963616c69666f6e69613111300f060355040713086d
#69706c69746173311b3019060355040a1312636973636f2073797374656d
#7320696e632e310e300c060355040b13054e535354473116301406035504
#03130d436872697374696e652059616e311d301b06092a864886f70d0109
#01160e6379616e40636973636f2e636f6d30820122300d06092a864886f7
#0d01010105000382010f003082010a02820101009c22f1d01af397756ab6
#cfce92a9e761b73fbf1efd070aa4e90448e6077e2c127ff47a5951de7790
#55da014ff152576a08d7199b8ad5757eb8c9a7c1a493715df2176e9f56f0
#74735d43420cf1ed17fe0aa3494724808aefcf274572c7750be071a94560
#9c045c48a5454f9e7933bf93d967bcf582918b1bbd48f47dd978c7ea9c88
#23eb01482a40ef770f823ea2e63eaf7cab5367bd51b54979925464e27b22
#82fc5bfe94f6f41f2f91e56444ae371a050107fe79fd5db3f228bbbd5fcb
#653a87a3c1268d74500ba1489382290804d9d7937d3269b1c55eae51f9f7
#62eadbd4226ba6d4008414b353181ee6cfbe24204e4a82436b117c255014
#77ec74c3ac4d0203010001a38201003081fd301d0603551d0e041604149c
#0e12d3a222891fc1300b780f38b54e07e228073081cd0603551d230481c5
#3081c280149c0e12d3a222891fc1300b780f38b54e07e22807a1819ea481
#9b308198310b300906035504061302434131123010060355040813096361
#6c69666f6e69613111300f060355040713086d69706c69746173311b3019
#060355040a1312636973636f2073797374656d7320696e632e310e300c06
#0355040b13054e53535447311630140603550403130d436872697374696e
#652059616e311d301b06092a864886f70d010901160e6379616e40636973
#636f2e636f6d820900d48b1bbfb069e9b9300c0603551d13040530030101
#ff300d06092a864886f70d010105050003820101003e6d657e30c21acb30
#d7e91aef99cd6f83a8644d7ae437fb4a0cd1a8c6a0f1cb2194be80868b75
#1d20ee8dc72a1f80de697928820ec3f806cec67df136d6f8b6ff0ba7ef6f
#e4c228b37e7407becff9903198ebe2258d3774f198de8d0366cb10496408
#57dff62f247dfcae9813fde4167c1f959b291490cfb8e0b8db3395ce019f
#07c94aa4a86d1a0dae2b6cc6d139db740841dc65add58512ea59336dbc8c
#9abc14d500e42c8ea5031c201eec027d14e9878974629d2fdbe0d0cfffab
#8ab73f148bdec788de59550443ccf12cb3e74518274c3d7d2892eeb90f23
#0d5e853b85542c05b12198c097c2fb4023b370f0629645e11552f5429fb8
#aacef60a9344b5318202823082027e0201013081a6308198310b30090603
#55040613024341311230100603550408130963616c69666f6e6961311130
#0f060355040713086d69706c69746173311b3019060355040a1312636973
#636f2073797374656d7320696e632e310e300c060355040b13054e535354
#47311630140603550403130d436872697374696e652059616e311d301b06
#092a864886f70d010901160e6379616e40636973636f2e636f6d020900d4
#8b1bbfb069e9b9300906052b0e03021a0500a081b1301806092a864886f7
#0d010903310b06092a864886f70d010701301c06092a864886f70d010905
#310f170d3037313231393233343434335a302306092a864886f70d010904
#311604142df670d9fda42f836ab9e7f5fdc30f445af55ee6305206092a86
#4886f70d01090f31453043300a06082a864886f70d0307300e06082a8648
#86f70d030202020080300d06082a864886f70d0302020140300706052b0e
#030207300d06082a864886f70d0302020128300d06092a864886f70d0101
#010500048201000642290febc470b074c1fcf17870208113594110f60898
#3a607ae6f563821c4acef0466100d56340d076361d863855ab8d4b913224
#0f1173a0129880ff98119e3d4457ffb64b63f22691aff8f8b68d5be84f90
#347b5d0023d7ef03fca725602507994c1116daaea43c4298644c1bdb3c2e
#cdf4396cbb5d18fdec3e93cc74c62a1e53ced19cbb5f158fdadb32387b05
#c8e6f05510050ec806ef481a871a1cb9fc3804dded5097f87f205d90eaa9
#697d1c0d526fbe78d38430e6317461386bb70bb3eda63e5792b53989ae1d
#0eef050ce738a4a5391a8e713cc451c4370fbb2c8e9f1a7188de41801930
#cd34ad8ecd280c6872fdf307618013001313cbda0c0fc4
#
