#------------------------------------------------------------------------------
# Diagnostic script to undeploy ospf policies. 
#
# Octomer 2007 - Christine Yan (cyan@cisco.com)
#
# Copyright (c) 2007-2008 by cisco Systems, Inc.
# All rights reserved.
#
#
# Version-date: v1.0-10/17/2007 
# Title: unregister ospf policies and remove their environment variables. 
# 
# Name: sdiag_ospf_undeploy.tcl
#
# Desc: 
#
#------------------------------------------------------------------------------

set user_lib_dir [exec show event man dir user lib]
if {[regexp "not configured" $user_lib_dir match]} {
    error "User library directory is not configured"
}

source [file join $user_lib_dir diag_lib.tcl]

set error "\nFOR OSPF SCRIPTS"
append error "\nUsage:tclsh disk#:/dir_name/sdiag_ospf_undeploy.tcl <ospf_adj_duplicate_rid.tcl> OR <ospf_intf_down_detached.tcl> OR <ospf_miss_area_id.tcl> OR <ospf_stuck_cases.tcl> OR <ospf_timer_expired.tcl>"


if {$argc == 0} {
    puts "\n\nSERVICE-DIAGNOSTICS ERROR: No arguments were given"
    puts $error
    return
} elseif {$argc == 1} {
    set type [lindex $argv 0]
}

set ospf_env_configured 0

switch $type {
    ospf_adj_duplicate_rid.tcl {
        set ospf_env [exec show event manager env | i _adj]
        if [regexp "adj" $ospf_env] {
            ios_config "no event manager env _send_email_for_adj_duplicate_rid"
            ios_config "no event manager env _verbose_for_adj_duplicate_rid"
            ios_config "no event manager environment _svcdiag_adjConfigHistory"
            ios_config "no event manager environment _svcdiag_adjEventHistory"
            set ospf_env_configured 1
        }
    }
    ospf_intf_down_detached.tcl {
        set ospf_env [exec show event manager env | i _intf]
        if [regexp "intf_down" $ospf_env] {
            set email_intf_down _send_email_for_intf_down_detached
            ios_config "no event manager env $email_intf_down"
            ios_config "no event manager env _verbose_for_intf_down_detached"
            set intf_config_history _svcdiag_intfConfigHistory
            ios_config "no event manager environment $intf_config_history"
            ios_config "no event manager environment _svcdiag_intfEventHistory"
            set ospf_env_configured 1
        }
    }
    ospf_miss_area_id.tcl {
        set ospf_env [exec show event manager env | i _miss]
        if [regexp "miss_area_id" $ospf_env] {
            ios_config "no event manager env _send_email_for_miss_area_id"
            ios_config "no event manager env _verbose_for_miss_area_id"
            set miss_config_history _svcdiag_missConfigHistory
            ios_config "no event manager environment $miss_config_history"
            ios_config "no event manager environment _svcdiag_missEventHistory"
            set ospf_env_configured 1
        }
    }
    ospf_stuck_cases.tcl {
        set ospf_env [exec show event manager env | i _stuck]
        if [regexp "stuck_cases" $ospf_env] {
            ios_config "no event manager env _send_email_for_stuck_cases"
            ios_config "no event manager env _verbose_for_stuck_cases"
            set stuck_config_history _svcdiag_stuckConfigHistory
            ios_config "no event manager environment $stuck_config_history"
            set stuck_event_history _svcdiag_stuckEventHistory
            ios_config "no event manager environment $stuck_event_history"
            set ospf_env_configured 1
        }
    }
    ospf_timer_expired.tcl {
        set ospf_env [exec show event manager env | i _timer]
        if [regexp "timer" $ospf_env] {
            ios_config "no event manager env _send_email_for_timer_expired"
            ios_config "no event manager env _verbose_for_timer_expired"
            set timer_config_history _svcdiag_timerConfigHistory
            ios_config "no event manager environment $timer_config_history"
            set timer_event_history _svcdiag_timerEventHistory
            ios_config "no event manager environment $timer_event_history"
            set ospf_env_configured 1
        }
    }
}

set error "\n\nSERVICE DIAGNOSTICS ERROR:\n"
if { $ospf_env_configured == 0 } {
    append error "\nThe policy \"$type\" "
    append error "and its related inputs were not deployed"
    puts $error
} else {
    unreg_eem_policy $type
}

#Cisco Tcl Signature V1.0
#3082077506092a864886f70d010702a082076630820762020101310b3009
#06052b0e03021a0500300b06092a864886f70d010701a08204bb308204b7
#3082039fa003020102020900d48b1bbfb069e9b9300d06092a864886f70d
#0101050500308198310b3009060355040613024341311230100603550408
#130963616c69666f6e69613111300f060355040713086d69706c69746173
#311b3019060355040a1312636973636f2073797374656d7320696e632e31
#0e300c060355040b13054e53535447311630140603550403130d43687269
#7374696e652059616e311d301b06092a864886f70d010901160e6379616e
#40636973636f2e636f6d301e170d3037313231383138333232375a170d31
#30313231373138333232375a308198310b30090603550406130243413112
#30100603550408130963616c69666f6e69613111300f060355040713086d
#69706c69746173311b3019060355040a1312636973636f2073797374656d
#7320696e632e310e300c060355040b13054e535354473116301406035504
#03130d436872697374696e652059616e311d301b06092a864886f70d0109
#01160e6379616e40636973636f2e636f6d30820122300d06092a864886f7
#0d01010105000382010f003082010a02820101009c22f1d01af397756ab6
#cfce92a9e761b73fbf1efd070aa4e90448e6077e2c127ff47a5951de7790
#55da014ff152576a08d7199b8ad5757eb8c9a7c1a493715df2176e9f56f0
#74735d43420cf1ed17fe0aa3494724808aefcf274572c7750be071a94560
#9c045c48a5454f9e7933bf93d967bcf582918b1bbd48f47dd978c7ea9c88
#23eb01482a40ef770f823ea2e63eaf7cab5367bd51b54979925464e27b22
#82fc5bfe94f6f41f2f91e56444ae371a050107fe79fd5db3f228bbbd5fcb
#653a87a3c1268d74500ba1489382290804d9d7937d3269b1c55eae51f9f7
#62eadbd4226ba6d4008414b353181ee6cfbe24204e4a82436b117c255014
#77ec74c3ac4d0203010001a38201003081fd301d0603551d0e041604149c
#0e12d3a222891fc1300b780f38b54e07e228073081cd0603551d230481c5
#3081c280149c0e12d3a222891fc1300b780f38b54e07e22807a1819ea481
#9b308198310b300906035504061302434131123010060355040813096361
#6c69666f6e69613111300f060355040713086d69706c69746173311b3019
#060355040a1312636973636f2073797374656d7320696e632e310e300c06
#0355040b13054e53535447311630140603550403130d436872697374696e
#652059616e311d301b06092a864886f70d010901160e6379616e40636973
#636f2e636f6d820900d48b1bbfb069e9b9300c0603551d13040530030101
#ff300d06092a864886f70d010105050003820101003e6d657e30c21acb30
#d7e91aef99cd6f83a8644d7ae437fb4a0cd1a8c6a0f1cb2194be80868b75
#1d20ee8dc72a1f80de697928820ec3f806cec67df136d6f8b6ff0ba7ef6f
#e4c228b37e7407becff9903198ebe2258d3774f198de8d0366cb10496408
#57dff62f247dfcae9813fde4167c1f959b291490cfb8e0b8db3395ce019f
#07c94aa4a86d1a0dae2b6cc6d139db740841dc65add58512ea59336dbc8c
#9abc14d500e42c8ea5031c201eec027d14e9878974629d2fdbe0d0cfffab
#8ab73f148bdec788de59550443ccf12cb3e74518274c3d7d2892eeb90f23
#0d5e853b85542c05b12198c097c2fb4023b370f0629645e11552f5429fb8
#aacef60a9344b5318202823082027e0201013081a6308198310b30090603
#55040613024341311230100603550408130963616c69666f6e6961311130
#0f060355040713086d69706c69746173311b3019060355040a1312636973
#636f2073797374656d7320696e632e310e300c060355040b13054e535354
#47311630140603550403130d436872697374696e652059616e311d301b06
#092a864886f70d010901160e6379616e40636973636f2e636f6d020900d4
#8b1bbfb069e9b9300906052b0e03021a0500a081b1301806092a864886f7
#0d010903310b06092a864886f70d010701301c06092a864886f70d010905
#310f170d3038313030333231343230365a302306092a864886f70d010904
#3116041490069ef0aace56f3ccb94b621959f460b4c5c4a4305206092a86
#4886f70d01090f31453043300a06082a864886f70d0307300e06082a8648
#86f70d030202020080300d06082a864886f70d0302020140300706052b0e
#030207300d06082a864886f70d0302020128300d06092a864886f70d0101
#010500048201008deddcda2326c381e84facd7a068532c5a493754215620
#69d8114e6569b148073df90e53dae826ed7d2223409555757242518a9de0
#06dc9235d0dccdb233a9c621e2c52a78e67a0c8bce94c1d94644ef12d7f1
#2dd6f0cfedf807cd581c02e5df689984f7552e28f3dd018d996e973116d1
#ff05e0234c889b17977fda26ea40cae30469abef16dc07709b79671944d7
#a8f91668da82f7307be3fc78f15598a4e7aeb198e3758e48154cdd512e20
#abd4704e48058216307e6153a16cb30d1718ad666c58722042b02241f74f
#3e918b85b815bcee4a5c5aa8a19f1f2505fb17590e097c629aa5966075a5
#36908889be16ee2d7b82000bfbc656f0090abc113929d7
